const express = require('express');

const router = express.Router();

const AdService = require('../service/AdService');
const utils = require('../utils/writer.js');
const upload = require('../multer-config');
const {extractToken} = require("../utils/writer");


router.post('/', extractToken, upload.array('photos'), async (req, res) => {
    try {
        const response = await AdService.addAdWithPhotos(req.body, req.files, req.token);
        if (!response) {
            return res.status(500).json({ message: 'Internal Server Error' });
        }

        if (response.status === undefined) {
            res.json(response);
        } else {
            res.status(response.status).json(response);
        }
    } catch (error) {
        console.error('Error in POST /ads:', error);
        res.status(500).json({ message: 'Internal Server Error' });
    }
});


router.get('/', extractToken, async (req, res) => {
    try {
        const response = await AdService.getAds(req.token);
        if (response.status === undefined) {
            res.json(response);
        } else {
            res.status(response.status).json(response);
        }
    } catch (error) {
        res.status(500).json({message: error.message});
    }
});
router.post('/:id/photos', extractToken, upload.array('photos'), async (req, res) => {
    try {
        const response = await AdService.addPhotosToAd(req.params.id, req.files, req.token);
        if (response.status === undefined) {
            res.json(response);
        } else {
            res.status(response.status).json(response);
        }
    } catch (error) {
        res.status(500).json({message: error.message});
    }
});

router.put('/:id', extractToken, upload.array('photos'), async (req, res) => {
    try {
        const response = await AdService.updateAd(req.params.id, req.body, req.files, req.token);
        if (response.status === undefined) {
            res.json(response);
        } else {
            res.status(response.status).json(response);
        }
    } catch (error) {
        res.status(500).json({message: error.message});
    }
});

router.delete('/:id', extractToken, async (req, res) => {
    try {
        const response = await AdService.deleteAd(req.params.id, req.token);
        if (response.status === undefined) {
            res.json(response);
        } else {
            res.status(response.status).json(response);
        }
    } catch (error) {
        res.status(500).json({message: error.message});
    }
});

router.get('/:id', extractToken, async (req, res) => {
    try {
        const response = await AdService.getAdById(req.params.id, req.token);
        if (response.status === 404) {
            res.status(404).json(response);
        } else {
            utils.writeJson(res, response);
        }
    } catch (error) {
        res.status(500).json({ message: error.message });
    }
});

router.put('/:id/ask', extractToken, async (req, res) => {
    const adtId = req.params.id;
    const {question} = req.body;
    try {
        const response = await AdService.askQuestion(adtId, question, req.token);
        if (response.status === undefined) {
            res.json(response);
        } else {
            res.status(response.status).json(response);
        }
    } catch (error) {
        res.status(500).json({message: error.message});
    }
});

router.put('/:id/question/:questionId/answer', extractToken, async (req, res) => {
    const adtId = req.params.id;
    const questionId = req.params.questionId;
    const {answer} = req.body;
    try {
        const response = await AdService.answerQuestion(adtId, questionId, answer, req.token);
        if (response.status === undefined) {
            res.json(response);
        } else {
            res.status(response.status).json(response);
        }
    } catch (error) {
        res.status(500).json({message: error.message});
    }
});

module.exports = router;
